collective.z3cform.chosen Installation
=================================================================================

To install collective.z3cform.chosen, follow this `documentation <http://plone.org/documentation/kb/installing-add-ons-quick-how-to>`_. 

